==> php-devel-pack-8.0.30-Win32-vs16-x64.zip: php-8.0.30-devel-vs16-x64-SSE4.2/script/ext_deps.js <==
PHP_PHPDBG_WEBHELPER=true;
PHP_PHPDBG_WEBHELPER_SHARED=true;
PHP_BCMATH=true;
PHP_BCMATH_SHARED=false;
PHP_BZ2=true;
PHP_BZ2_SHARED=true;
PHP_CALENDAR=true;
PHP_CALENDAR_SHARED=false;
PHP_COM_DOTNET=true;
PHP_COM_DOTNET_SHARED=true;
PHP_CTYPE=true;
PHP_CTYPE_SHARED=false;
PHP_CURL=true;
PHP_CURL_SHARED=true;
PHP_DATE=true;
PHP_DATE_SHARED=false;
PHP_DBA=true;
PHP_DBA_SHARED=true;
PHP_ENCHANT=true;
PHP_ENCHANT_SHARED=true;
PHP_FFI=true;
PHP_FFI_SHARED=false;
PHP_FILEINFO=true;
PHP_FILEINFO_SHARED=true;
PHP_FILTER=true;
PHP_FILTER_SHARED=false;
PHP_FTP=true;
PHP_FTP_SHARED=true;
PHP_GD=true;
PHP_GD_SHARED=true;
PHP_GETTEXT=true;
PHP_GETTEXT_SHARED=true;
PHP_GMP=true;
PHP_GMP_SHARED=true;
PHP_HASH=true;
PHP_HASH_SHARED=false;
PHP_ICONV=true;
PHP_ICONV_SHARED=false;
PHP_IMAP=true;
PHP_IMAP_SHARED=true;
PHP_INTL=true;
PHP_INTL_SHARED=true;
PHP_JSON=true;
PHP_JSON_SHARED=false;
PHP_LDAP=true;
PHP_LDAP_SHARED=true;
PHP_MBSTRING=true;
PHP_MBSTRING_SHARED=true;
PHP_MYSQLND=true;
PHP_MYSQLND_SHARED=false;
PHP_OCI8=true;
PHP_OCI8_SHARED=true;
PHP_OCI8_12C=true;
PHP_OCI8_12C_SHARED=true;
PHP_OCI8_19=true;
PHP_OCI8_19_SHARED=true;
PHP_ODBC=true;
PHP_ODBC_SHARED=true;
PHP_OPCACHE=true;
PHP_OPCACHE_SHARED=true;
PHP_OPENSSL=true;
PHP_OPENSSL_SHARED=true;
PHP_PCRE=true;
PHP_PCRE_SHARED=false;
PHP_PGSQL=true;
PHP_PGSQL_SHARED=true;
PHP_READLINE=true;
PHP_READLINE_SHARED=false;
PHP_REFLECTION=true;
PHP_REFLECTION_SHARED=false;
PHP_SESSION=true;
PHP_SESSION_SHARED=false;
PHP_SHMOP=true;
PHP_SHMOP_SHARED=true;
PHP_SNMP=true;
PHP_SNMP_SHARED=true;
PHP_SOCKETS=true;
PHP_SOCKETS_SHARED=true;
PHP_SODIUM=true;
PHP_SODIUM_SHARED=true;
PHP_SPL=true;
PHP_SPL_SHARED=false;
PHP_SQLITE3=true;
PHP_SQLITE3_SHARED=true;
PHP_STANDARD=true;
PHP_STANDARD_SHARED=false;
PHP_SYSVSHM=true;
PHP_SYSVSHM_SHARED=true;
PHP_TIDY=true;
PHP_TIDY_SHARED=true;
PHP_TOKENIZER=true;
PHP_TOKENIZER_SHARED=false;
PHP_ZEND_TEST=true;
PHP_ZEND_TEST_SHARED=true;
PHP_ZIP=true;
PHP_ZIP_SHARED=false;
PHP_ZLIB=true;
PHP_ZLIB_SHARED=false;
PHP_LIBXML=true;
PHP_LIBXML_SHARED=false;
PHP_DOM=true;
PHP_DOM_SHARED=false;
PHP_EXIF=true;
PHP_EXIF_SHARED=true;
PHP_MYSQLI=true;
PHP_MYSQLI_SHARED=true;
PHP_PDO=true;
PHP_PDO_SHARED=false;
PHP_PDO_FIREBIRD=true;
PHP_PDO_FIREBIRD_SHARED=true;
PHP_PDO_MYSQL=true;
PHP_PDO_MYSQL_SHARED=true;
PHP_PDO_OCI=true;
PHP_PDO_OCI_SHARED=true;
PHP_PDO_ODBC=true;
PHP_PDO_ODBC_SHARED=true;
PHP_PDO_PGSQL=true;
PHP_PDO_PGSQL_SHARED=true;
PHP_PDO_SQLITE=true;
PHP_PDO_SQLITE_SHARED=true;
PHP_PHAR=true;
PHP_PHAR_SHARED=false;
PHP_SIMPLEXML=true;
PHP_SIMPLEXML_SHARED=false;
PHP_SOAP=true;
PHP_SOAP_SHARED=true;
PHP_XML=true;
PHP_XML_SHARED=false;
PHP_XMLREADER=true;
PHP_XMLREADER_SHARED=false;
PHP_XMLWRITER=true;
PHP_XMLWRITER_SHARED=false;
PHP_XSL=true;
PHP_XSL_SHARED=true;

==> php-devel-pack-8.1.33-Win32-vs16-x64.zip: php-8.1.33-devel-vs16-x64-SSE4.2/script/ext_deps.js <==
PHP_BCMATH=true;
PHP_BCMATH_SHARED=false;
PHP_BZ2=true;
PHP_BZ2_SHARED=true;
PHP_CALENDAR=true;
PHP_CALENDAR_SHARED=false;
PHP_COM_DOTNET=true;
PHP_COM_DOTNET_SHARED=true;
PHP_CTYPE=true;
PHP_CTYPE_SHARED=false;
PHP_CURL=true;
PHP_CURL_SHARED=true;
PHP_DATE=true;
PHP_DATE_SHARED=false;
PHP_DBA=true;
PHP_DBA_SHARED=true;
PHP_DL_TEST=true;
PHP_DL_TEST_SHARED=true;
PHP_ENCHANT=true;
PHP_ENCHANT_SHARED=true;
PHP_FFI=true;
PHP_FFI_SHARED=true;
PHP_FILEINFO=true;
PHP_FILEINFO_SHARED=true;
PHP_FILTER=true;
PHP_FILTER_SHARED=false;
PHP_FTP=true;
PHP_FTP_SHARED=true;
PHP_GD=true;
PHP_GD_SHARED=true;
PHP_GETTEXT=true;
PHP_GETTEXT_SHARED=true;
PHP_GMP=true;
PHP_GMP_SHARED=true;
PHP_HASH=true;
PHP_HASH_SHARED=false;
PHP_ICONV=true;
PHP_ICONV_SHARED=false;
PHP_IMAP=true;
PHP_IMAP_SHARED=true;
PHP_INTL=true;
PHP_INTL_SHARED=true;
PHP_JSON=true;
PHP_JSON_SHARED=false;
PHP_LDAP=true;
PHP_LDAP_SHARED=true;
PHP_MBSTRING=true;
PHP_MBSTRING_SHARED=true;
PHP_MYSQLND=true;
PHP_MYSQLND_SHARED=false;
PHP_OCI8=true;
PHP_OCI8_SHARED=true;
PHP_OCI8_12C=true;
PHP_OCI8_12C_SHARED=true;
PHP_OCI8_19=true;
PHP_OCI8_19_SHARED=true;
PHP_ODBC=true;
PHP_ODBC_SHARED=true;
PHP_OPCACHE=true;
PHP_OPCACHE_SHARED=true;
PHP_OPENSSL=true;
PHP_OPENSSL_SHARED=true;
PHP_PCRE=true;
PHP_PCRE_SHARED=false;
PHP_PGSQL=true;
PHP_PGSQL_SHARED=true;
PHP_READLINE=true;
PHP_READLINE_SHARED=false;
PHP_REFLECTION=true;
PHP_REFLECTION_SHARED=false;
PHP_SESSION=true;
PHP_SESSION_SHARED=false;
PHP_SHMOP=true;
PHP_SHMOP_SHARED=true;
PHP_SNMP=true;
PHP_SNMP_SHARED=true;
PHP_SOCKETS=true;
PHP_SOCKETS_SHARED=true;
PHP_SODIUM=true;
PHP_SODIUM_SHARED=true;
PHP_SPL=true;
PHP_SPL_SHARED=false;
PHP_SQLITE3=true;
PHP_SQLITE3_SHARED=true;
PHP_STANDARD=true;
PHP_STANDARD_SHARED=false;
PHP_SYSVSHM=true;
PHP_SYSVSHM_SHARED=true;
PHP_TIDY=true;
PHP_TIDY_SHARED=true;
PHP_TOKENIZER=true;
PHP_TOKENIZER_SHARED=false;
PHP_ZEND_TEST=true;
PHP_ZEND_TEST_SHARED=true;
PHP_ZIP=true;
PHP_ZIP_SHARED=false;
PHP_ZLIB=true;
PHP_ZLIB_SHARED=false;
PHP_LIBXML=true;
PHP_LIBXML_SHARED=false;
PHP_DOM=true;
PHP_DOM_SHARED=false;
PHP_EXIF=true;
PHP_EXIF_SHARED=true;
PHP_MYSQLI=true;
PHP_MYSQLI_SHARED=true;
PHP_PDO=true;
PHP_PDO_SHARED=false;
PHP_PDO_FIREBIRD=true;
PHP_PDO_FIREBIRD_SHARED=true;
PHP_PDO_MYSQL=true;
PHP_PDO_MYSQL_SHARED=true;
PHP_PDO_OCI=true;
PHP_PDO_OCI_SHARED=true;
PHP_PDO_ODBC=true;
PHP_PDO_ODBC_SHARED=true;
PHP_PDO_PGSQL=true;
PHP_PDO_PGSQL_SHARED=true;
PHP_PDO_SQLITE=true;
PHP_PDO_SQLITE_SHARED=true;
PHP_PHAR=true;
PHP_PHAR_SHARED=false;
PHP_SIMPLEXML=true;
PHP_SIMPLEXML_SHARED=false;
PHP_SOAP=true;
PHP_SOAP_SHARED=true;
PHP_XML=true;
PHP_XML_SHARED=false;
PHP_XMLREADER=true;
PHP_XMLREADER_SHARED=false;
PHP_XMLWRITER=true;
PHP_XMLWRITER_SHARED=false;
PHP_XSL=true;
PHP_XSL_SHARED=true;
